@@ -9,7 +9,7 @@ use Astro::Coord::ECI::TLE;
 use Carp;
 
 our @ISA = qw{ Astro::Coord::ECI::TLE };
-our $VERSION = '0.133_01';
+our $VERSION = '0.078';
 
 my $pkg = __PACKAGE__;
 
@@ -26,6 +26,7 @@ sub period {
     return $self->{$pkg}{period};
 }
 
+
 1;
 
 __END__
@@ -73,9 +74,7 @@ L<Astro::Coord::ECI::TLE|Astro::Coord::ECI::TLE>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass>,
-L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -83,7 +82,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2017-2025 by Thomas R. Wyant, III
+Copyright (C) 2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
