@@ -50,7 +50,7 @@ package Astro::Coord::ECI::Sun;
 use strict;
 use warnings;
 
-our $VERSION = '0.077';
+our $VERSION = '0.078';
 
 use base qw{Astro::Coord::ECI};
 
@@ -77,10 +77,10 @@ our $Singleton = $weaken;
 =item $sun = Astro::Coord::ECI::Sun->new();
 
 This method instantiates an object to represent the coordinates of the
-Sun. This is a subclass of B<Astro::Coord::ECI>, with the id and name
-attributes set to 'Sun', and the diameter attribute set to 1392000 km
-per Jean Meeus' "Astronomical Algorithms", 2nd Edition, Appendix I,
-page 407.
+Sun. This is a subclass of L<Astro::Coord::ECI|Astro::Coord::ECI>, with
+the id and name attributes set to 'Sun', and the diameter attribute set
+to 1392000 km per Jean Meeus' "Astronomical Algorithms", 2nd Edition,
+Appendix I, page 407.
 
 Any arguments are passed to the set() method once the object has been
 instantiated. Yes, you can override the "hard-wired" id, name, and so
@@ -492,20 +492,21 @@ Algorithms" (second edition) formed the basis for this module.
 
 =head1 SEE ALSO
 
-The C<Astro::Coord::ECI::OVERVIEW|Astro::Coord::ECI::OVERVIEW>
+The L<Astro::Coord::ECI::OVERVIEW|Astro::Coord::ECI::OVERVIEW>
 documentation for a discussion of how the pieces/parts of this
 distribution go together and how to use them.
 
-The B<Astro-MoonPhase> package by Brett Hamilton, which contains a
-function-based module to compute the current phase, distance and
-angular diameter of the Moon, as well as the angular diameter and
-distance of the Sun.
+L<Astro::MoonPhase|Astro::MoonPhase> by Brett Hamilton, which contains a
+function-based module to compute the current phase, distance and angular
+diameter of the Moon, as well as the angular diameter and distance of
+the Sun.
 
-The B<Astro-Sunrise> package by Ron Hill, which contains a function-based
-module to compute sunrise and sunset for the given day and location.
+L<Astro::Sunrise|Astro::Sunrise> by Ron Hill and Jean Forget, which
+contains a function-based module to compute sunrise and sunset for the
+given day and location.
 
-The B<Astro-SunTime> package by Rob Fugina, which provides functionality
-similar to B<Astro-Sunrise>.
+L<Astro::SunTime|Astro::SunTime> by Rob Fugina, which provides
+functionality similar to B<Astro-Sunrise>.
 
 =head1 AUTHOR
 
@@ -513,7 +514,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2016 by Thomas R. Wyant, III
+Copyright (C) 2005-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
